summaryrefslogtreecommitdiff
path: root/src/w16select.c
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2010-10-23 19:13:37 -0700
committerGlenn Morris <rgm@gnu.org>2010-10-23 19:13:37 -0700
commit3646b86d0ed250ed89d5cf40b731ef55fb46f052 (patch)
treedea64cdf7156f8b5eecc4ec522207a9457fc9a80 /src/w16select.c
parent8aa0f26343d11229fb87cd6a4473598b99b6b9a2 (diff)
downloademacs-3646b86d0ed250ed89d5cf40b731ef55fb46f052.tar.gz
emacs-3646b86d0ed250ed89d5cf40b731ef55fb46f052.tar.bz2
emacs-3646b86d0ed250ed89d5cf40b731ef55fb46f052.zip
Sync Lisp and C docs of next-selection-coding-system.
* src/w16select.c (syms_of_win16select) <next-selection-coding-system>: * src/w32select.c (syms_of_w32select) <next-selection-coding-system>: Sync docs with select.el. * lisp/select.el (next-selection-coding-system): Sync doc with C versions.
Diffstat (limited to 'src/w16select.c')
-rw-r--r--src/w16select.c15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/w16select.c b/src/w16select.c
index 4d471e97911..75d88b558e2 100644
--- a/src/w16select.c
+++ b/src/w16select.c
@@ -1,6 +1,7 @@
/* 16-bit Windows Selection processing for emacs on MS-Windows
- Copyright (C) 1996, 1997, 2001, 2002, 2003, 2004,
- 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+
+Copyright (C) 1996, 1997, 2001, 2002, 2003, 2004, 2005, 2006, 2007,
+ 2008, 2009, 2010 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -700,11 +701,11 @@ The default value is `iso-latin-1-dos'. */);
Vselection_coding_system = intern ("iso-latin-1-dos");
DEFVAR_LISP ("next-selection-coding-system", &Vnext_selection_coding_system,
- doc: /* Coding system for the next communication with other X clients.
+ doc: /* Coding system for the next communication with other programs.
Usually, `selection-coding-system' is used for communicating with
-other X clients. But, if this variable is set, it is used for the
-next communication only. After the communication, this variable is
-set to nil. */);
+other programs (X Windows clients or MS Windows programs). But, if this
+variable is set, it is used for the next communication only.
+After the communication, this variable is set to nil. */);
Vnext_selection_coding_system = Qnil;
QPRIMARY = intern ("PRIMARY"); staticpro (&QPRIMARY);
@@ -713,5 +714,3 @@ set to nil. */);
#endif /* MSDOS */
-/* arch-tag: 085a22c8-7324-436e-a6da-102464ce95d8
- (do not change this comment) */